# Form implementation generated from reading ui file './server/gui/server_gui_clients.ui'
#
# Created by: PyQt6 UI code generator 6.4.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtWidgets


class Ui_ClientsWindow(object):
    def setupUi(self, ClientsWindow):
        ClientsWindow.setObjectName("ClientsWindow")
        ClientsWindow.resize(429, 466)
        self.verticalLayout = QtWidgets.QVBoxLayout(ClientsWindow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tableWidget = QtWidgets.QTableWidget(ClientsWindow)
        self.tableWidget.setObjectName("tableWidget")
        self.tableWidget.setColumnCount(0)
        self.tableWidget.setRowCount(0)
        self.verticalLayout.addWidget(self.tableWidget)

        self.retranslateUi(ClientsWindow)
        QtCore.QMetaObject.connectSlotsByName(ClientsWindow)

    def retranslateUi(self, ClientsWindow):
        _translate = QtCore.QCoreApplication.translate
        ClientsWindow.setWindowTitle(_translate("ClientsWindow", "Список клиентов"))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    ClientsWindow = QtWidgets.QWidget()
    ui = Ui_ClientsWindow()
    ui.setupUi(ClientsWindow)
    ClientsWindow.show()
    sys.exit(app.exec())
