# Form implementation generated from reading ui file './server/gui/server_gui_history.ui'
#
# Created by: PyQt6 UI code generator 6.4.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtWidgets


class Ui_HistoryWindow(object):
    def setupUi(self, HistoryWindow):
        HistoryWindow.setObjectName("HistoryWindow")
        HistoryWindow.resize(618, 480)
        self.verticalLayout = QtWidgets.QVBoxLayout(HistoryWindow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tableWidget = QtWidgets.QTableWidget(HistoryWindow)
        self.tableWidget.setObjectName("tableWidget")
        self.tableWidget.setColumnCount(0)
        self.tableWidget.setRowCount(0)
        self.verticalLayout.addWidget(self.tableWidget)

        self.retranslateUi(HistoryWindow)
        QtCore.QMetaObject.connectSlotsByName(HistoryWindow)

    def retranslateUi(self, HistoryWindow):
        _translate = QtCore.QCoreApplication.translate
        HistoryWindow.setWindowTitle(_translate("HistoryWindow", "История клиентов"))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    HistoryWindow = QtWidgets.QWidget()
    ui = Ui_HistoryWindow()
    ui.setupUi(HistoryWindow)
    HistoryWindow.show()
    sys.exit(app.exec())
